@@ -21,7 +21,7 @@
  * <fwpg@sharif.edu>.
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <string.h>
 
