@@ -183,7 +183,7 @@ LANGUAGE(
 LANGUAGE(
 	 fa	/* Persian */,
 	 MISC	/* Behdad Esfahbod (#548730) */,
-	 "«الا یا اَیُّها السّاقی! اَدِرْ کَأساً وَ ناوِلْهٰا!» که عشق آسان نمود اوّل، ولی افتاد مشکل‌ها!"
+	 "«الا یا اَیُّها السّاقی! اَدِرْ کَأساً وَ ناوِلْها!» که عشق آسان نمود اوّل، ولی افتاد مشکل‌ها!"
 	)
 LANGUAGE(
 	 fi	/* Finnish */,
@@ -247,9 +247,9 @@ LANGUAGE(
 	)
 LANGUAGE(
 	 hi	/* Hindi */,
-	 GLASS,
-	 "मैं काँच खा सकता हूँ, मुझे उस से कोई पीडा नहीं होती."
-	 /* I can eat glass and it doesn't hurt me. */
+	 MISC	/* G Karunakar (#549532) */,
+	 "नहीं नजर किसी की बुरी नहीं किसी का मुँह काला जो करे सो उपर वाला"
+	 /* its not in the sight or the face, but its all in god's grace. */
 	)
 LANGUAGE(
 	 hr	/* Croatian */,
