@@ -1,5 +1,5 @@
 /* Pango
- * pangox.h:
+ * pangoxft.h:
  *
  * Copyright (C) 1999 Red Hat Software
  * Copyright (C) 2000 SuSE Linux Ltd
@@ -50,8 +50,10 @@ typedef void (*PangoXftSubstituteFunc) (FcPattern *pattern,
  */
 PangoFontMap *pango_xft_get_font_map     (Display *display,
 					  int      screen);
+#ifndef PANGO_DISABLE_DEPRECATED
 PangoContext *pango_xft_get_context      (Display *display,
 					  int      screen);
+#endif
 void          pango_xft_shutdown_display (Display *display,
 					  int      screen);
 
@@ -63,13 +65,13 @@ void pango_xft_set_default_substitute (Display                *display,
 void pango_xft_substitute_changed     (Display                *display,
 				       int                     screen);
 
-GType pango_xft_font_map_get_type (void);
+GType pango_xft_font_map_get_type (void) G_GNUC_CONST;
 
 #define PANGO_XFT_FONT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_XFT_FONT, PangoXftFont))
 #define PANGO_TYPE_XFT_FONT              (pango_xft_font_get_type ())
 #define PANGO_XFT_IS_FONT(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_XFT_FONT))
 
-GType      pango_xft_font_get_type (void);
+GType      pango_xft_font_get_type (void) G_GNUC_CONST;
 
 /* For shape engines
  */
